#!/usr/bin/perl
# $Id: snmp_get_sysDescr.pl,v 1.4 2002/02/21 17:30:53 gadsden Exp $
#
# Usage: snmp_get_sysDescr.pl [-p port] [-t timeout] [-r retries]
#                             DestHost [ Community ]
#
#  where timeout := microseconds before retry, default 250000 (ie .25s)
#        retries := number of retries, default 2
#        port := remote udp port, default 161
#        DestHost := name or address of target host
#        Community := SNMP community string, default public
#
# Author: Richard Gadsden <gadsden@musc.edu>
#         Medical University of South Carolina
#         Charleston, SC, USA

use SNMP;
use Socket;
use Getopt::Std;

getopts('p:t:r:');
$port    = defined($opt_p) ? $opt_p : 161;
$timeout = defined($opt_t) ? $opt_t : 250000;
$retries = defined($opt_r) ? $opt_r : 2;

my $host = shift;
my $comm = shift || "public";

if ($host =~ /[a-zA-Z]/) {
  $name = $host;
  $iaddr = gethostbyname($name);
  if ($iaddr) { $addr = inet_ntoa($iaddr); }
  else { exit; }
}

$result = &snmp_get(DestHost=>$host, Community=>$comm, RemotePort=>$port,
                    Timeout=>$timeout, Retries=>$retries, "sysDescr.0");

if (defined($result)) { 
  if ($host !~ /[a-zA-Z]/) {
    $addr = $host;
    $name = gethostbyaddr(inet_aton($addr), AF_INET);
  }
  $result =~ tr/[\n\r]/ /;
  print "$addr\t$name\t$result\n"; 
}
